@@ -1,14 +1,13 @@
 import os
 import json
 
-from datetime import datetime
-
 import jwt
 import flask
 import requests
 
 
-BASE_API_URL = os.getenv('API_SERVER', '')
+BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
+APP_SERVICE_BASE_URL = os.getenv('APP_SERVICE_BASE_URL', '')
 
 
 def get_jwt_token():
@@ -62,3 +61,30 @@ def generate_pdf(oap_name, data, size='A3', route=None):
     res = requests.post(url, data=post_data).json()
 
     return res
+
+
+def get_run_result(run_id):
+
+    def _get_run_result(url):
+        resp = requests.get(url)
+        analysis_run = resp.json()
+
+        if resp.ok and analysis_run:
+            flask.session[run_id] = json.dumps(analysis_run['result'])
+            result = analysis_run['result']
+        else:
+            result = {}
+        
+        return result
+
+    if run_id:
+        str_result = flask.session.get(run_id)
+        if str_result:
+            result = json.loads(str_result)
+        else:
+            url = APP_SERVICE_BASE_URL + f'/oap-api/v1/analysis-runs/{run_id}/'
+            result = _get_run_result(url)
+    else:
+        result = {}
+
+    return result
